@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2015 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # PyHoca CLI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -454,19 +454,25 @@ class PyHocaCLI(x2go.X2GoClient):
                 try:
                     self._X2GoClient__connect_session(self.x2go_session_hash, username=_username, password=self.args.password, force_password_auth=force_password_auth)
                     connected = True
+                    force_password_auth = False
                 except x2go.PasswordRequiredException, e:
                     self._pyhoca_logger('unlock SSH key file (%s)' % self.args.ssh_privkey, loglevel=x2go.loglevel_NOTICE, )
                     self.args.password = getpass.getpass()
                 except x2go.AuthenticationException, e:
                     force_password_auth = True
-                    self._pyhoca_logger('interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
-                    self.args.password = getpass.getpass()
+                    self._pyhoca_logger('passwordless login for ,,%s\'\' failed' % _username, loglevel=x2go.loglevel_WARN, )
+                    self._pyhoca_logger('proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
                 except x2go.BadHostKeyException:
                     self._runtime_error('SSH host key verification for remote host [%s]:%s failed' % (self.args.server, self.args.remote_ssh_port), exitcode=-254)
                 except x2go.SSHException, e:
-                    if str(e) != 'not a valid DSA private key file':
+                    if str(e) not in ('not a valid DSA private key file', 'Incompatible ssh peer (no acceptable kex algorithm)', 'No authentication methods available'):
                         self._runtime_error(str(e), exitcode=253)
                     force_password_auth = True
+                    self._pyhoca_logger('passwordless login for ,,%s\'\' failed' % _username, loglevel=x2go.loglevel_WARN, )
+                    self._pyhoca_logger('proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
+
+                if force_password_auth:
+                    self.args.password = getpass.getpass()
 
                 # workaround for Python bug: http://bugs.python.org/issue11236
                 try:
